@@ -21,26 +21,30 @@
 #include <qfont.h>
 #include <qwidget.h>
 
-#include "msnobject.h"
-
 // Forward declarations
 class KConfig;
 class KMessTest;
+class MsnObject;
 
-/**A user account.
-  *@author Mike K. Bennett
-  */
-
-class Account : public QWidget
+/**
+ * @brief Data class for user account settings.
+ *
+ * The properties of this class correspond with the profile section in the <code>kmessrc</code> file.
+ * The data is read with the readProperties() method and saved with the saveProperties() method.
+ * When the user switches to another account, the data is copied to the CurrentAccount class with
+ * the copyAccount() method. The <code>set*</code> methods are issued from the SettingsDialog code.
+ * When the account is disconnected, the data is copied back and saved to disk.
+ *
+ * @author Mike K. Bennett
+ * @ingroup Root
+ */
+class Account : public QObject
 {
   Q_OBJECT
 
   friend class KMessTest;
 
   public: // Public methods
-    enum PROXYTYPE { TYPE_HTTP = 0, TYPE_SOCKS4, TYPE_SOCKS5 };
-
-
     // Directory structure constants
     enum ChatDirectoryStructure { SINGLEDIRECTORY = 0
                                 , BYYEAR          = 1
@@ -56,10 +60,12 @@ class Account : public QWidget
     virtual void                 copyAccount( const Account *account );
     // Copy an account's user-interface, not settings, changable properties
     void                         copyAccountUISettings( const Account *account );
+    // Delete the account data
+    void                         deleteAccountData();
     // Read the auto-reply message.
     const QString&               getAutoreplyMessage() const;
-    // Return the chat format string.
-    const QString&               getChatFormat() const;
+    // Return the chat style name.
+    const QString&               getChatStyle() const;
     // Return the font used for contact messages, if forced to.
     const QFont&                 getContactFont() const;
     // Return the color of the forced contact font.
@@ -74,24 +80,32 @@ class Account : public QWidget
     const QString&               getFontColor() const;
     // Return the user's friendlyName
     QString                      getFriendlyName() const;
+    // Whether follow-up messages from the contact should be grouped.
+    bool                         getGroupFollowupMessages() const;
     // Return the user's handle
     QString                      getHandle() const;
     // Return the length of time waited before the user goes idle.
     const int&                   getIdleTime() const;
+    // Return the status to set upon connection
+    QString                      getInitialStatus() const;
     // Return the time popup windows are shown.
     const int&                   getNotificationDuration() const;
+    // Return if popup notifications will be shown for contacts which come online.
+    bool                         getNotifyContactsOnline() const;
+    // Return if popup notifications will be shown for contacts which change their msn status.
+    bool                         getNotifyContactsStatus() const;
+    // Return if popup notifications will be shown for contacts which start a chat with you.
+    bool                         getNotifyContactsChatStart() const;
+    // Return if popup notifications will be shown for all received chat messages.
+    bool                         getNotifyContactsChatMessages() const;
+    // Return if popup notifications will be shown for contacts which go offline.
+    bool                         getNotifyContactsOffline() const;
+    // Return if popup notifications will be shown for incoming mail.
+    bool                         getNotifyEmails() const;
     // Return the user's password
     QString                      getPassword() const;
-    // Return the proxy password
-    const QString&               getProxyPassword() const;
-    // Return the proxy port
-    const int&                   getProxyPort() const;
-    // Return the proxy server IP
-    const QString&               getProxyServer() const;
-    // Return the proxy server type
-    const int&                   getProxyType() const;
-    // Return the user's proxy user ID
-    const QString&               getProxyUID() const;
+    // Return the personal message
+    QString                      getPersonalMessage() const;
    // Return whether or not to save chats.
     bool                         getSaveChats() const;
     // Return the base directory to which chats are saved.
@@ -104,18 +118,24 @@ class Account : public QWidget
     bool                         getShowContactsByGroup() const;
     // Read whether the email information should be shown in the main view.
     bool                         getShowEmail() const;
+    // Read the selected emoticon's list number
+    const QString&               getEmoticonStyle() const;
+    // Read whether the chat window should shake when a nudge is received or sent.
+    bool                         getShakeNudge() const;
     // Read whether offline contacts should be shown.
     bool                         getShowOfflineContacts() const;
-    // Read property of bool showOfflineNotification_.
-    bool                         getShowOfflineNotification() const;
+    // Read property of bool showMessageTime.
+    bool                         getShowMessageTime() const;
+    // Return whether now listening information should be displayed.
+    bool                         getShowNowListening() const;
     // Read property of bool showOtherFolders.
     bool                         getShowOtherFolders() const;
     // Read whether or not removed (reverse) contacts are shown.
     bool                         getShowRemovedContacts() const;
     // Read whether or not the sidebar should be shown in chats
     bool                         getShowSidebar() const;
-    // Return whether or not to start in "hidden" mode
-    bool                         getStartInvisible() const;
+    // Return the a temporary password for the account for login attempts from the initialview dialog
+    const QString &              getTemporaryPassword() const;
     // Return whether or not to autologin with this profile.
     bool                         getUseAutologin() const;
     // Return whether or not to show contact messages in the stored font.
@@ -128,30 +148,36 @@ class Account : public QWidget
     bool                         getUseHotmail() const;
     // Return whether the idle timer should be used.
     bool                         getUseIdleTimer() const;
-    // Return whether or not to show popup notifications.
-    bool                         getUseNotifier() const;
-    // Return whether or not to use a proxy.
-    bool                         getUseProxy() const;
     // Returns whether or not to send our display image
     bool                         getShowImage() const;
-    // Returns whether or not to show a custom image
-    bool                         getCustomImage() const;
     // Return the path of the custom display image.
     const QString                getCustomImagePath() const;
     // Return the path to the *current* display image
     const QString                getImagePath() const;
     // Returns the string representation of the MsnObject
     const QString                getMsnObjectString() const;
+    // Return the path for a new the custom display image.
+    QString                      getNewCustomImagePath();
+    // Whether the account is marked to be deleted
+    bool                         isDeleted() const;
+    // Whether the account has unsaved settings changes
+    bool                         isDirty() const;
+    // Whether the account is a guest account, not permanently saved on the computer
+    bool                         isGuestAccount() const;
+    // Return whether the account's passport is verified
+    bool                         isVerified() const;
     // Read in account properties
     void                         readProperties(KConfig *config, QString  handle);
     // Save account properties
     void                         saveProperties(KConfig *config);
+    // The login succeeded with the new password. Save the temporary password as new account password.
+    void                         saveTemporaryPassword();
     // Set alert information
-    void                         setAlertsInformation( bool useIdleTimer, int idleTime, bool useNotifier, int notificationDuration, bool showOfflineNotification);
+    void                         setAlertsInformation( bool useIdleTimer, int idleTime, bool shakeNudge, bool showNowListening );
     // Set the auto-reply message.
     void                         setAutoreplyMessage( const QString&  autoreplyMessage);
     // Set chat information
-    void                         setChatInformation( bool useContactFont, bool useEmoticons, bool useFontEffects, const QString& chatFormat );
+    void                         setChatInformation( bool useContactFont, bool useEmoticons, bool useFontEffects, bool showMessageTime, bool groupFollowupMessages, const QString& chatStyle );
     // Set chat logging information
     void                         setChatLoggingInformation( bool saveChats, const QString& saveChatPath, const int& directoryStructure );
     // Set email information
@@ -164,10 +190,32 @@ class Account : public QWidget
     void                         setFontInformation( const QFont& font, const QString  &fontColor, const QFont& contactFont, const QString  &contactFontColor);
     // Change the friendly name
     void                         setFriendlyName( const QString&  newName );
-    // Set proxy information
-    void                         setProxyInformation( bool useproxy, const int& proxytype,const QString& proxyserver, const int& proxyport,const QString& proxyuid, const QString& password );
+    // Set the emoticon folder
+    void                         setEmoticonStyle( const QString& emoticonStyle );
+    // Whether the account is a guest account, not permanently saved on the computer
+    void                         setGuestAccount( bool guestAccount );
+    // Change the status to set upon connection
+    void                         setInitialStatus( QString status );
+    // change the personal message
+    void                         setPersonalMessage( const QString& newMessage );
     // Set basic account data
     void                         setLoginInformation( QString  handle, QString  friendlyName, QString  password = "" );
+    // Set notification alerts information
+    void                         setNotificationsInformation( bool doNotifyContactsOnline, bool doNotifyContactsStatus,
+                                                              bool doNotifyContactsChatStart, bool doNotifyContactsChatMessages,
+                                                              bool doNotifyContactsOffline, bool doNotifyEmails, int notificationDuration );
+    // Set whether to show popup notifications when contacts come online.
+    void                         setNotifyContactsOnline( bool doNotifyContactsOnline );
+    // Set whether to show popup notifications when contacts change their msn status.
+    void                         setNotifyContactsStatus( bool doNotifyContactsStatus );
+    // Set whether to show popup notifications when contacts start a chat with you.
+    void                         setNotifyContactsChatStart( bool doNotifyContactsChatStart );
+    // Set whether to show popup notifications for all received chat messages.
+    void                         setNotifyContactsChatMessages( bool doNotifyContactsChatMessages );
+    // Set whether to show popup notifications when contacts go offline.
+    void                         setNotifyContactsOffline( bool doNotifyContactsOffline );
+    // Set whether to show popup notifications for incoming mail.
+    void                         setNotifyEmails( bool doNotifyEmails );
     // Set whether or not allowed contacts are shown.
     void                         setShowAllowedContacts( bool showAllowedContacts );
     // Set whether contacts are shown by group or by online/offline.
@@ -178,16 +226,16 @@ class Account : public QWidget
     void                         setShowRemovedContacts( bool showRemovedContacts );
     // Set whether or not the sidebar should be shown in chats
     void                         setShowSidebar( bool showSidebar );
-    // Set whether or not to start in "hidden" mode
-    void                         setStartInvisible( bool startInvisible );
+    // Set a temporary password for the account for login attempts from the initialview dialog
+    void                         setTemporaryPassword( const QString &temporaryPassword );
     // Set whether or not to login with this account.
     void                         setUseAutologin( bool useAutologin);
     // Set whether or not to show emoticons in chats.
     void                         setUseEmoticons( bool useEmoticons);
+    // Set whether the account's passport is verified
+    void                         setVerified( bool verified );
     // Set whether or not to send our display image
     void                         setShowImage( bool showImage );
-    // Set whether or not to show a custom display image
-    void                         setCustomImage( bool customImage );
     // Creates the MsnObject only if the user wants to show a display picture
     void                         updateMsnObject();
 
@@ -198,29 +246,53 @@ class Account : public QWidget
   private: // Private attributes
     // The message used to automatically reply to messages when the user is away.
     QString                      autoreplyMessage_;
-    // The chat format, with the {time}, {name}, and {message} elements.
-    QString                      chatFormat_;
+    // The chat style
+    QString                      chatStyle_;
     // The message font to be used by contact messages.
     QFont                        contactFont_;
     // The font color to be applied to contact messages.
     QString                      contactFontColor_;
+    // The number of the custom image
+    int                          customImageIndex_;
+    // Whether the account is marked to be deleted
+    bool                         deleted_;
     // Whether the account has been changed at all
     bool                         dirty_;
+    // Show a notification when contacts come online?
+    bool                         doNotifyContactsOnline_;
+    // Show a notification when contacts change their status?
+    bool                         doNotifyContactsStatus_;
+    // Show a notification when contacts start a chat?
+    bool                         doNotifyContactsChatStart_;
+    // Show a notification everywhen contacts send you messages?
+    bool                         doNotifyContactsChatMessages_;
+    // Show a notification when contacts go offline?
+    bool                         doNotifyContactsOffline_;
+    // Show a notification when receiving new mail?
+    bool                         doNotifyEmails_;
     // The external command used, optionally, to open email
     QString                      emailCommand_;
     // Whether the user can receive email notifications (hotmail.com or msn.com account)
     bool                         emailSupported_;
+    // The directory of a selected emoticon
+    QString                      emoticonStyle_;
     // The user's message font.
     QFont                        font_;
     // The user's message font color.
     QString                      fontColor_;
     // The user's friendly name, i.e. "Mike"
     QString                      friendlyName_;
+    // Whether the account is a "guest account", not permanently saved on the computer
+    bool                         guestAccount_;
+    // Whether follow-up messages from the contact should be grouped.
+    bool                         groupFollowupMessages_;
     // The user's handle, i.e. mkb137b@hotmail.com
     QString                      handle_;
     // The number of minutes of inactivity before the user status is
     //  changed to idle.
     int                          idleTime_;
+    // The status to connect as
+    QString                      initialStatus_;
     // The duration in seconds that a notification balloon is shown.
     int                          notificationDuration_;
     // The user's password
@@ -231,6 +303,8 @@ class Account : public QWidget
     bool                         saveChats_;
     // Whether saved chats are organized by year, month, day, or all in a single directory
     int                          savedChatDirectoryStructure_;
+    // Whether the chat window shakes for nudges
+    bool                         shakeNudge_;
     // Whether or not allowed contacts should be visible.
     bool                         showAllowedContacts_;
     // Whether contacts should be shown by group (true) or by online/offline status (false).
@@ -238,18 +312,20 @@ class Account : public QWidget
     // Whether or not to show any email notifications (the user may not
     //  have a hotmail account).
     bool                         showEmail_;
+    // Whether or not time information is shown for chat messages.
+    bool                         showMessageTime_;
+    // Whether now listening information should be shown or not.
+    bool                         showNowListening_;
     // Whether or not offline contacts are shown.
     bool                         showOfflineContacts_;
-    // Whether or not "contact is offline" notifications are shown.
-    bool                         showOfflineNotification_;
     // Whether or not notifications should be shown for "other folder" email.
     bool                         showOtherFolders_;
     // Whether or not removed (or reverse) contacts should be visible.
     bool                         showRemovedContacts_;
     // Whether or not the sidebar should be shown in chats
     bool                         showSidebar_;
-    // Whether or not to start in "hidden" mode
-    bool                         startInvisible_;
+    // A temporary password for the account for login attempts from the initialview dialog
+    QString                      temporaryPassword_;
     // Whether or not to autologin with this user.
     bool                         useAutologin_;
     // Whether or not the contact's font should be forced to some value.
@@ -262,41 +338,40 @@ class Account : public QWidget
     bool                         useHotmail_;
     // Whether or not the user wants to go idle after a certain time.
     bool                         useIdleTimer_;
-    // Whether or not to show notification messages (balloons)
-    bool                         useNotifier_;
-    //Whether or not to use a proxy
-    bool                         useProxy_;
-    // The proxy type
-    PROXYTYPE                    proxyType_;
-    // The proxy host
-    QString                      proxyServer_;
-    // The proxy port
-    int                          proxyPort_;
-    // The proxy User ID
-    QString                      proxyUID_;
-    // The proxy user's password
-    QString                      proxyPassword_;
+    // Whether the account's passport is verified
+    bool                         verified_;
+    // the user's personal message
+    QString                      personalMessage_;
     // Whether or not to send our display image
     bool                         showImage_;
-    // whether or not to use a custom display image
-    bool                         customImage_;
     // MsnObject representing our display picture if we have one
     MsnObject                    *msnObject_;
+
   signals: // Public signals
+    // Signal that the chat style settings have been changed
+    void                         changedChatStyleSettings();
     // Signal that group/contact display settings have been changed
     void                         changedDisplaySettings();
     // Signal that the user changed email display settings
     void                         changedEmailDisplaySettings();
+    // Signal that the emoticon settings changed
+    void                         changedEmoticonSettings();
     // Signal that font settings have changed
     void                         changedFontSettings();
     // Signal that the friendly name has changed
     void                         changedFriendlyName();
-    // SIgnal that the msn object has changed.
+    // Signal that the msn object has changed.
     void                         changedMsnObject();
+    // Signal that the now listening settings have changed
+    void                         changedNowListeningSettings();
+    // Signal that the personal message has changed
+    void                         changedPersonalMessage();
     // Signal that timer settings were changed
     void                         changedTimerSettings();
     // Signal that the view mode has changed
     void                         changedViewMode();
+    // Signal that tray notifications settings were changed
+    void                         changedNotificationsSettings();
 };
 
 #endif
