@@ -20,10 +20,15 @@
 
 #include <qwidget.h>
 
-/**The view widget used when the contact is logging in automatically.
-  *@author Mike K. Bennett
-  */
-
+/**
+ * @brief The login status message widget.
+ *
+ * This class displays the "Logging in..." status message
+ * in the main window, and displays the KMess icon.
+ *
+ * @author Mike K. Bennett
+ * @ingroup Root
+ */
 class AutologinView : public QWidget
 {
   Q_OBJECT
