@@ -42,7 +42,7 @@
 
 // The constructor
 ChatWindowInterface::ChatWindowInterface(QWidget *parent, const char *name )
- : KDockMainWindow(parent,name)
+ : KMainWindow(parent,name)
 {
   // Create the menus
   initMenus();
@@ -114,6 +114,22 @@ void ChatWindowInterface::editPaste()
 
 
 
+// enlarge the text size
+void ChatWindowInterface::editZoomIn()
+{
+  kdDebug() << "ChatWindowInterface::editZoomIn() implemented" << endl;
+}
+
+
+
+// decrease the text size
+void ChatWindowInterface::editZoomOut()
+{
+  kdDebug() << "ChatWindowInterface::editZoomOut() implemented" << endl;
+}
+
+
+
 // The emoticon button was pressed.
 void ChatWindowInterface::emoticonButtonPressed()
 {
@@ -122,7 +138,7 @@ void ChatWindowInterface::emoticonButtonPressed()
 
 
 
-// Close the chat window
+// close the chat window
 void ChatWindowInterface::fileClose()
 {
   close();
@@ -143,7 +159,7 @@ void ChatWindowInterface::helpContents()
 // Create the chat menu
 void ChatWindowInterface::initChatMenu()
 {
-  KAction     *close, *save, *send, *meeting;
+  KAction     *close, *save, *send, *meeting, *nudge;
 #ifdef HAS_KPHONE
   KAction     *conversation;
 #endif
@@ -154,15 +170,16 @@ void ChatWindowInterface::initChatMenu()
 
   // Create the "chat" menus
   inviteMenu_ = new KPopupMenu( this, "connect");
-  send    = new KAction( i18n("Send a &File"),        "folder_open",      KShortcut(), this, SLOT( transferFile() ), actionCollection(), "sendfile");
+  send    = new KAction( i18n("Send a &File"),        "folder_open",      KShortcut(), this, SLOT( slotStartFileTransfer() ), actionCollection(), "sendfile");
   meeting = new KAction( i18n("Start a &Meeting"),    "gnomemeeting",     KShortcut(), this, SLOT( startMeeting() ), actionCollection(), "startmeeting");
+  nudge =   new KAction( i18n("Send a &Nudge!"),          "bell",     KShortcut(), this, SLOT( slotSendNudge() ),actionCollection(), "sendnudge");
 #ifdef HAS_KPHONE  //If KPhone is not enable than don't support voice conversation
   conversation = new KAction( i18n("Start or Stop a &Conversation"),    "kphone",     KShortcut(), this, SLOT( startConversation() ), actionCollection(), "startconversation");
 #endif
 
 
 
-  save = KStdAction::save( this, SLOT( saveChat() ), actionCollection() );
+  save  = new KAction( i18n("Save chat"), "filesave", KShortcut(), this, SLOT( saveChat() ), actionCollection(), "savelog");
   close = KStdAction::close( this, SLOT( fileClose() ), actionCollection() );
 
   // Plug the items into "chat"
@@ -173,11 +190,16 @@ void ChatWindowInterface::initChatMenu()
 #ifdef HAS_KPHONE  //If KPhone is not enable than don't support voice conversation
   conversation->plug( chatMenu );
 #endif  
+  chatMenu->insertSeparator();
+  nudge->   plug( chatMenu );
   chatMenu->insertSeparator();
   save->    plug( chatMenu );
   close->   plug( chatMenu );
+
+  // Also plug the icons into the toolbar
   close->   plug( toolBar("mainToolBar") );
   send->    plug( toolBar("mainToolBar") );
+  nudge->   plug( toolBar("mainToolBar") );
 
   // Plug the menu into the menubar
   menuBar()->insertItem( i18n("&Chat"), chatMenu );
@@ -189,7 +211,7 @@ void ChatWindowInterface::initChatMenu()
 void ChatWindowInterface::initEditMenu()
 {
   KAction         *changeFont, *changeFontColor;
-  KAction         *cut, *copy, *paste;
+  KAction         *cut, *copy, *paste, *zoomIn, *zoomOut;
   KPopupMenu      *editMenu;
 
   // Create the menu
@@ -201,18 +223,33 @@ void ChatWindowInterface::initEditMenu()
   cut = KStdAction::cut( this, SLOT( editCut() ), actionCollection() );
   copy = KStdAction::copy( this, SLOT( editCopy() ), actionCollection() );
   paste = KStdAction::paste( this, SLOT( editPaste() ), actionCollection() );
+  zoomIn = KStdAction::zoomIn( this, SLOT( editZoomIn() ), actionCollection() );
+  zoomOut = KStdAction::zoomOut( this, SLOT( editZoomOut() ), actionCollection() );
 
   // Plug the items into "edit"
   cut->            plug( editMenu );
   copy->           plug( editMenu );
   paste->          plug( editMenu );
+  editMenu->insertSeparator();
   changeFont->     plug( editMenu );
   changeFontColor->plug( editMenu );
-  cut->            plug( toolBar("mainToolBar") );
-  copy->           plug( toolBar("mainToolBar") );
-  paste->          plug( toolBar("mainToolBar") );
-  changeFont->     plug( toolBar("mainToolBar") );
-  changeFontColor->plug( toolBar("mainToolBar") );
+  editMenu->insertSeparator();
+  zoomIn->         plug( editMenu );
+  zoomOut->        plug( editMenu );
+
+  // Plug the icons to the toolbar.
+  KToolBar *mainToolBar = toolBar("mainToolBar");
+  mainToolBar->insertLineSeparator();
+  cut->            plug( mainToolBar );
+  copy->           plug( mainToolBar );
+  paste->          plug( mainToolBar );
+  changeFont->     plug( mainToolBar );
+  changeFontColor->plug( mainToolBar );
+  mainToolBar->insertLineSeparator();
+  zoomIn->         plug( mainToolBar );
+  zoomOut->        plug( mainToolBar );
+  mainToolBar->insertLineSeparator();
+
 
   // Plug the menu into the menubar
   menuBar()->insertItem( i18n("&Edit"), editMenu );
@@ -257,15 +294,15 @@ void ChatWindowInterface::initMenus()
   initEditMenu();
   initSettingsMenu();
   initHelpMenu();
-  // Create the emoticons button
-  emoticonButton_ = new KToolBarButton( "emoticons", 0, toolBar("mainToolBar"), "emoticonchooser");
-  // Connect the button
-  connect( emoticonButton_, SIGNAL( pressed() ),
-           this, SLOT( emoticonButtonPressed() ) );
 
+  // Create the emoticons button
+  KToolBar *mainToolBar = toolBar("mainToolBar");
+  emoticonButton_ = new KToolBarButton( "emoticons", 0, mainToolBar, "emoticonchooser");
   emoticonButton_->setText( i18n("Insert an emoticon") );
+  connect( emoticonButton_, SIGNAL( pressed() ), this, SLOT( emoticonButtonPressed() ));
+
   // Plug the sidebar button in after the emoticon button.
-  sidebarAction_-> plug( toolBar("mainToolBar") );
+  sidebarAction_-> plug( mainToolBar );
 }
 
 
@@ -398,6 +435,20 @@ void ChatWindowInterface::startConversation()
 
 
 
+void ChatWindowInterface::slotSendNudge()
+{
+  kdDebug() << "ChatWindowInterface::slotSendNudge not implemented" << endl;
+}
+
+
+
+// Send a file to a contact.
+void ChatWindowInterface::slotStartFileTransfer( QStringList /*uriList*/ )
+{
+  kdDebug() << "ChatWindowInterface::slotStartFileTransfer not implemented" << endl;
+}
+
+
 // Change the status bar message.
 void ChatWindowInterface::statusMessage(QString /*message*/)
 {
@@ -421,13 +472,4 @@ void ChatWindowInterface::toggleSidebar()
 }
 
 
-
-// Send a file to a contact.
-void ChatWindowInterface::transferFile()
-{
-  kdDebug() << "ChatWindowInterface::transferFile not implemented" << endl;
-}
-
-
-
 #include "chatwindowinterface.moc"
