@@ -99,46 +99,22 @@ void ContactAction::updateVisibility()
   bool  shouldBePlugged;
 
 #ifdef KMESSDEBUG_CONTACTACTION
-  kdDebug() << "ContactAction - Checking visibility for " << contact_->getFriendlyName() << "." << endl;
+  kdDebug() << "ContactAction - Checking visibility for " << contact_->getHandle() << "." << endl;
 #endif
-  if ( inChat_ )
-  {
-    // Contacts in the chat can not be invited
-    shouldBePlugged = false;
-  }
-  else
-  {
-    // The contact is not in the chat...
-    if ( contact_->getStatus() == "FLN" )
-    {
-      // Offline contacts can not be invited
-      shouldBePlugged = false;
-    }
-    else
-    {
-      // The contact is online...
-      if ( contact_->isFriend() )
-      {
-        // Friends can be invited
-        shouldBePlugged = true;
-      }
-      else
-      {
-        // Anything else can't be
-        shouldBePlugged = false;;
-      }
-    }
-  }
+
+  shouldBePlugged = ( ! inChat_ && contact_->isOnline() && contact_->isFriend() );
+
 #ifdef KMESSDEBUG_CONTACTACTION
   kdDebug() << "ContactAction - Should be plugged = " << shouldBePlugged << "." << endl;
 #endif
+
   // Plug the contact in if it should be plugged and it's not
-  if ( shouldBePlugged && !plugged_ )
+  if ( shouldBePlugged && ! plugged_ )
   {
     plug( menu_ );
     plugged_ = true;
   }
-  else if ( !shouldBePlugged && plugged_ )
+  else if ( ! shouldBePlugged && plugged_ )
   { // Unplug the contact if it's plugged but shouldn't be
     unplug( menu_ );
     plugged_ = false;
