@@ -28,7 +28,6 @@
 #include <kdebug.h>
 #include <kglobal.h>
 #include <khelpmenu.h>
-#include <kled.h>
 #include <klocale.h>
 #include <kmenubar.h>
 #include <knotifydialog.h>
@@ -38,6 +37,7 @@
 #include <kstdaction.h>
 #include <ktoolbar.h>
 #include <kurl.h>
+#include <kmessagebox.h>
 
 #include "kmessdebug.h"
 #include "kmessapplication.h"
@@ -46,7 +46,7 @@
 // The constructor
 KMessInterface::KMessInterface(QWidget *parent, const char *name )
  : KMainWindow(parent,name)
- , connectState_(0)
+ , connectState_(TYPE_ERROR)
  , initialized_(false)
 {
 
@@ -139,20 +139,19 @@ void KMessInterface::configureNotifications()
 // Create the "Actions" menu
 void KMessInterface::createActionsMenu()
 {
-  KAction         *newAccount, *searchForContact, *searchByInterest, *themes;
+  KAction         *newAccount, *searchForContact, *searchByInterest;
   KPopupMenu      *actionsMenu;
   // Create the menu
   actionsMenu = new KPopupMenu( this, "actionsmenu" );
 
   // Create the "settings" menus
   newAccount       = new KAction( i18n("New &Account"),        "filenew",      0, this, SLOT(           createNewAccount() ), actionCollection(), "newaccount");
-  newContact_      = new KAction( i18n("New &Contact"),        "filenew",      0, this, SLOT(              addNewContact() ), actionCollection(), "newcontact");
-  newGroup_        = new KAction( i18n("New &Group"),          "filenew",      0, this, SLOT(                addNewGroup() ), actionCollection(), "newgroup");
+  newContact_      = new KAction( i18n("New &Contact"),        "add_user",     0, this, SLOT(              addNewContact() ), actionCollection(), "newcontact");
+  newGroup_        = new KAction( i18n("New &Group"),          "folder_new",   0, this, SLOT(                addNewGroup() ), actionCollection(), "newgroup");
+  searchForContact = new KAction( i18n("S&earch for Contact"), "search_user",  0, this, SLOT(           searchForContact() ), actionCollection(), "searchforcontact");
+  searchByInterest = new KAction( i18n("Search by &Interest"), "filefind",     0, this, SLOT( searchForContactByInterest() ), actionCollection(), "searchbyinterest");
+  settingsActionMenu_ = new KActionMenu( i18n("Account &Settings"), "edit", this, "settings");
   configureNotifications_ = KStdAction::configureNotifications(this, SLOT(configureNotifications()), actionCollection());
-  settingsActionMenu_ = new KActionMenu( i18n("Account &Settings"), "misc", this, "settings");
-  searchForContact = new KAction( i18n("S&earch for Contact"), "find",         0, this, SLOT(           searchForContact() ), actionCollection(), "searchforcontact");
-  searchByInterest = new KAction( i18n("Search by &Interest"), "find",         0, this, SLOT( searchForContactByInterest() ), actionCollection(), "searchbyinterest");
-  themes = new KAction( i18n("Get New Emoticon or Sound &Themes"), "kmess",    0, this, SLOT(             goToThemesPage() ), actionCollection(), "themes");
 
   // Plug the items into "settings"
   newContact_             ->plug( actionsMenu );
@@ -165,7 +164,6 @@ void KMessInterface::createActionsMenu()
   settingsActionMenu_     ->plug( actionsMenu );
   actionsMenu->insertSeparator();
   configureNotifications_ ->plug( actionsMenu );
-  themes                  ->plug( actionsMenu );
   // Plug the menu into the menubar
   menuBar()->insertItem( i18n("&Actions"), actionsMenu );
 }
@@ -185,8 +183,8 @@ void KMessInterface::createConnectMenu()
   // Create the "connect" menu items
   connectActionMenu_ = new KActionMenu( i18n("Co&nnect"), "connect_creating", this, "connect");
   disconnect_ = new KAction( i18n("&Disconnect"), "connect_no", 0, this, SLOT( disconnectClicked() ), actionCollection(), "disconnect");
-  showProfile_ = new KAction( i18n("Show My &Profile"), "kmess", 0, this, SLOT( showUserProfile() ), actionCollection(), "showuserprofile");
-  status_ = new KSelectAction( i18n("&My Status"), "misc", 0, this, "status");
+  showProfile_ = new KAction( i18n("Show My &Profile"), "identity", 0, this, SLOT( showUserProfile() ), actionCollection(), "showuserprofile");
+  status_ = new KSelectAction( i18n("&My Status"), "goto", 0, this, "status");
   statuses << i18n("Online")
            << i18n("Away")
            << i18n("Away with auto-reply")
@@ -275,7 +273,7 @@ void KMessInterface::createViewMenu()
   showRemovedAction_ = new KToggleAction( i18n("Show &Removed Contacts"), 0, KShortcut(), this, "removed");
 
 #ifdef KMESS_NETWORK_WINDOW
-  showNetworkAction_ = new KAction(i18n("Show &Network Window"), "bookmark", 0,
+  showNetworkAction_ = new KAction(i18n("Show &Network Window"), "network_local", 0,
                                    this, SLOT(showNetworkWindow()), actionCollection(), "shownetwork");
 #endif
 
@@ -361,15 +359,6 @@ void KMessInterface::enableMenus(bool connected)
 
 
 
-// Open the kmess themes web page
-void KMessInterface::goToThemesPage()
-{
-  KURL  url( "http://kmess.sourceforge.net/index.php?page=themes" );
-  new KRun( url );
-}
-
-
-
 // Show the user manual for KMess.
 void KMessInterface::helpContents()
 {
@@ -398,9 +387,6 @@ bool KMessInterface::initialize()
   statusTimer_->setText( "00:00" );
   statusBar()->addWidget( statusTimer_, 0, true );
 
-  statusProgress_ = new KLed( this );
-  statusProgress_->setMaximumHeight( 16 );
-  statusBar()->addWidget( statusProgress_, 0, true );
 
   // Create the online timer
   onlineTimer_ = new QTimer( this );
@@ -424,7 +410,7 @@ void KMessInterface::menuClose()
   kdDebug() << "KMessInterface - 'Close' was selected from the menu." << endl;
 #endif
   // Hide the window
-  hide();
+  queryClose();  // To show the KMessageBox too
 #ifdef KMESSTEST
   ASSERT( isHidden() );
 #endif
@@ -451,6 +437,10 @@ void KMessInterface::menuQuit()
 // Reject quitting unless the quit menu was pressed  Called automatically by KMainWindow::closeEvent
 bool KMessInterface::queryExit()
 {
+#ifdef KMESSDEBUG_KMESSINTERFACE
+  kdDebug() << "KMessInterface::queryExit: Accepting exit request." << endl;
+#endif
+
   return true;
 }
 
@@ -462,16 +452,6 @@ bool KMessInterface::queryClose()
   // KMessApplication also defines sessionSaving() for KDE 3.1
   KMessApplication *app = static_cast<KMessApplication *>(kapp);
 
-//  if(! app->quitSelected())
-//  {
-//    // TODO: for KMess 1.5, display that KMess is still visible in the systray.
-//    KMessageBox::information( this,
-//                              i18n( "Closing the main window will keep KMess running in the "
-//                                    "system tray. Use 'Quit' from the 'File' menu to quit the application." ),
-//                              i18n( "Docking in System Tray" ), "hideOnCloseInfo" );
-//  }
-
-
 
   // Only allow KMess to quit if:
   // - the "quit" option was used from the menu
@@ -490,6 +470,14 @@ bool KMessInterface::queryClose()
     applicationClosing();
     return true;
   }
+  else
+  {
+    // Tell that KMess is still visible in the tray
+    KMessageBox::information( this,
+                              i18n( "Closing the main window will keep KMess running in the "
+                                    "system tray. Use 'Quit' from the 'File' menu to quit the application." ),
+                              i18n( "Docking in System Tray" ), "hideOnCloseInfo" );
+  }
 
 #ifdef KMESSDEBUG_KMESSINTERFACE
   kdDebug() << "KMessInterface::queryClose: Rejecting quit request, hiding window" << endl;
@@ -637,7 +625,7 @@ void KMessInterface::showUserProfile()
 
 
 // Change the status bar message.
-void KMessInterface::statusMessage( QString message, int connectState )
+void KMessInterface::statusMessage( QString message, ConnectionStatus connectState )
 {
 #ifdef KMESSDEBUG_KMESSINTERFACE
   kdDebug() << "STATUS MESSAGE " << message << endl;
@@ -650,17 +638,13 @@ void KMessInterface::statusMessage( QString message, int connectState )
   {
     switch ( connectState )
     {
-      case 1:
-        statusProgress_->setColor( "#00ff00" );
-
+      case TYPE_MESSAGE:
         onlineTime_ = 0;
         onlineTimer_->start( 60000 );
         break;
-      case 2:
-        statusProgress_->setColor( "#ffa000" );
+      case TYPE_WARNING: // No actions are needed for the warning messages
         break;
-      case 3:
-        statusProgress_->setColor( "#ff0000" );
+      case TYPE_ERROR:
 
         onlineTimer_->stop();
         statusTimer_->setText( "00:00" );
