@@ -25,46 +25,54 @@
 #include <kextsock.h>
 #include <klocale.h>
 
-#include "../msnftpconnection.h"
 #include "../mimemessage.h"
+#include "../extra/msnftpconnection.h"
 #include "../../currentaccount.h"
 #include "../../kmessdebug.h"
 
 // It wouldn't hurt if these GUI specific features are removed here.
 // That would make this class GUI-independant and only emit signals for possible GUI actions.
 #include <kfiledialog.h>
+#include <kmessagebox.h>
 #include "../../dialogs/transferwindow.h"
-#include "../../dialogs/transferentryinterface.h"
-#include "../../dialogs/transferentry.h"
+
 
 #ifdef KMESSDEBUG_FILETRANSFER
 #define KMESSDEBUG_FILETRANSFER_GENERAL
 #endif
 
-// The constructor
-FileTransfer::FileTransfer(const QString& authHandle, const QString& localIp)
-  : MimeApplication(localIp)
-  , authHandle_(authHandle)
+
+// The constructor without filename (sufficient for incoming sessions)
+FileTransfer::FileTransfer(const QString &contactHandle)
+  : MimeApplication(contactHandle)
+  , connectionEstablished_(false)
   , connectivity_('?')
   , file_(0)
   , msnFtpConnection_(0)
-  , transferPanel_(0)
+  , transferID_(-1)
 {
-
+  setApplicationType( ChatMessage::TYPE_APPLICATION_FILE );
 }
 
+// The constructor with filename to start a session
+FileTransfer::FileTransfer(const QString &contactHandle, const QString &filename)
+  : MimeApplication(contactHandle)
+  , connectionEstablished_(false)
+  , connectivity_('?')
+  , file_(0)
+  , fileName_(filename)
+  , msnFtpConnection_(0)
+  , transferID_(-1)
+{
+  setApplicationType( ChatMessage::TYPE_APPLICATION_FILE );
+}
 
 
 // The destructor
 FileTransfer::~FileTransfer()
 {
-  // Make sure the transfer panel displays the cancel state
-  if(transferPanel_ != 0)
-  {
-    // The object can be deleted by the user
-    transferPanel_->failTransfer();
-    transferPanel_ = 0;
-  }
+  // Displays the cancel state in the transfer window
+  TransferWindow::getInstance()->failTransfer( transferID_ );
 
   // Stop the ftp connection
   delete msnFtpConnection_;
@@ -85,6 +93,8 @@ void FileTransfer::connectMsnFtpConnection()
   ASSERT( msnFtpConnection_ != 0 );
 #endif
 
+  connect(msnFtpConnection_, SIGNAL(           connectionEstablished()         ) ,  // The direct connection was established
+          this,                SLOT( slotMsnFtpConnectionEstablished()         ) );
   connect(msnFtpConnection_, SIGNAL(              statusMessage(QString,int)   ) ,  // Display a message in the dialog/chat window
           this,                SLOT(    slotMsnFtpStatusMessage(QString,int)   ) );
   connect(msnFtpConnection_, SIGNAL(           transferComplete()              ) ,  // Signal that the transfer is complete
@@ -101,7 +111,7 @@ void FileTransfer::connectMsnFtpConnection()
 void FileTransfer::contactStarted1_ContactInvitesUser(const MimeMessage& message)
 {
 #ifdef KMESSDEBUG_FILETRANSFER_GENERAL
-  kdDebug() << "FileTransfer - contactStarted1_ContactInvitesUser" << endl;
+  kdDebug() << "FileTransfer::contactStarted1_ContactInvitesUser()" << endl;
 #endif
   QString html;
 
@@ -111,9 +121,9 @@ void FileTransfer::contactStarted1_ContactInvitesUser(const MimeMessage& message
   connectivity_  = message.getValue("Connectivity").at(0).latin1();
 
   // Send the message to the chat window.
-  html = i18n("Do you want to accept the file: %1 (%2 bytes)")
-         .arg( "<font color=red>" + shortFileName_ + "</font>" )
-         .arg( fileSize_ );
+  html = i18n("Do you want to accept the file: %1 (%2)")
+         .arg( "<span class=\"filename invitationFilename\">" + shortFileName_ + "</span>" )
+         .arg( toReadableBytes( fileSize_ ) );
 
   offerAcceptOrReject( html );
 }
@@ -124,63 +134,92 @@ void FileTransfer::contactStarted1_ContactInvitesUser(const MimeMessage& message
 void FileTransfer::contactStarted2_UserAccepts()
 {
 #ifdef KMESSDEBUG_FILETRANSFER_GENERAL
-  kdDebug() << "ReceiveFile - contactStarted2_UserAccepts" << endl;
+  kdDebug() << "FileTransfer::contactStarted2_UserAccepts()" << endl;
 #endif
 #ifdef KMESSTEST
   ASSERT( file_ == 0 );
 #endif
 
-  QString recentFolderTag = ":filedownload"; // Make it a QString()
-  KURL startDir;
   bool open;
+  QString startFolder;  // QString::null by default
+  QString recentFolderTag = ":filedownload";
 
-  // Get an initial path to the file
-  startDir = KFileDialog::getStartURL(QString::null, recentFolderTag);
-  startDir.addPath(shortFileName_);
-
-  // Open a file dialog so that the user can
-  // save the file to a particular directory and name.
-  // Give the last path + received short name as suggestion.
-  // This is one before the actual accept message is sent,
-  // so we can respond to the "cancel" button early.
-  fileName_ = KFileDialog::getSaveFileName( startDir.url() );
-
-  if(fileName_.isNull())
+  // Open a file dialog so that the user can save the file to a particular directory and name.
+  bool hasFile = false;
+  while( ! hasFile )
   {
-    // Dialog cancelled, cancel afterall
-    userRejected();
-    return;
-  }
-  else
-  {
-    // Create a file object, open for writing
-    file_ = new QFile(fileName_);
-    open  = file_->open(IO_WriteOnly);
-    if(! open)
+    // Set an initial path to the file
+    KURL startDir = KFileDialog::getStartURL( startFolder, recentFolderTag );
+    startDir.addPath( shortFileName_ );
+
+    delayDeletion( true );
+
+    // Ask the user for a file.
+    fileName_ = KFileDialog::getSaveFileName( startDir.url() );
+
+    delayDeletion( false );
+    if( isClosing() )
     {
-      // Important: undo what we created
-      delete file_;
-      file_     = 0;
-      fileName_ = QString::null;
-
-      // Cancel invitation afterall
-      sendCancelMessage(CANCEL_FAILED);
-      slotMsnFtpStatusMessage( i18n("The transfer of %1 failed.  Couldn't open file."), MsnFtpConnection::STATUS_CHAT );
       endApplication();
       return;
     }
-    else
-    {
-      // All passed. Send the accept message
-      MimeMessage message;
-      message.addField( "Invitation-Command", "ACCEPT"         );
-      message.addField( "Invitation-Cookie",  getCookie()      );
-      message.addField( "Launch-Application", "FALSE"          );
-      message.addField( "Request-Data",       "IP-Address:"    );
 
-      sendMessage( message );
+    if( fileName_.isNull() )
+    {
+#ifdef KMESSDEBUG_FILETRANSFER_GENERAL
+      kdDebug() << "FileTransfer::contactStarted2_UserAccepts() - User cancelled in file save dialog" << endl;
+#endif
+
+      // Dialog cancelled, cancel afterall
+      userRejected();
+      return;
+    }
+
+    hasFile = true;
+    QString shortName = fileName_.right( fileName_.length() - fileName_.findRev("/") - 1 );
+
+    // Check if the selected file exists and if the user wants to overwrite it.
+    // The while loop is for the prompt to keep appearing if the user
+    // chooses the same filename but does not want to overwrite the file.
+    if( QFile::exists(fileName_) )
+    {
+      if( KMessageBox::warningContinueCancel( 0,
+            i18n("The file '%1' already exists.\ndo you want to overwrite it?").arg(shortName),
+            i18n("Overwrite File"), KGuiItem( i18n("Over&write") ) ) == KMessageBox::Cancel )
+      {
+        // User does not want to override
+        hasFile     = false;
+        startFolder = fileName_.left( fileName_.findRev("/") );
+      }
     }
   }
+
+  // Create a file object, open for writing
+  file_ = new QFile(fileName_);
+  open  = file_->open(IO_WriteOnly);
+
+  if(! open)
+  {
+    // Important: undo what we created
+    delete file_;
+    file_     = 0;
+    fileName_ = QString::null;
+
+    // Cancel invitation afterall
+    slotMsnFtpStatusMessage( i18n("The transfer of %1 failed.  Couldn't open file."), MsnFtpConnection::STATUS_CHAT );
+    sendCancelMessage(CANCEL_FAILED);
+    return;
+  }
+
+
+  // All passed. Send the accept message
+  MimeMessage message;
+  message.addField( "Invitation-Command", "ACCEPT"         );
+  message.addField( "Invitation-Cookie",  getCookie()      );
+  message.addField( "Launch-Application", "FALSE"          );
+  message.addField( "Request-Data",       "IP-Address:"    );
+
+  sendMessage( message );
 }
 
 
@@ -189,7 +228,7 @@ void FileTransfer::contactStarted2_UserAccepts()
 void FileTransfer::contactStarted3_ContactConfirmsAccept(const MimeMessage& message)
 {
 #ifdef KMESSDEBUG_FILETRANSFER_GENERAL
-  kdDebug() << "FileTransfer - contactStarted3_ContactConfirmsAccept" << endl;
+  kdDebug() << "FileTransfer::contactStarted3_ContactConfirmsAccept()" << endl;
 #endif
 #ifdef KMESSTEST
   ASSERT( ! fileName_.isEmpty()      );
@@ -203,6 +242,7 @@ void FileTransfer::contactStarted3_ContactConfirmsAccept(const MimeMessage& mess
   int     port;
   int     portXInternal;
   int     portX;
+  QString authCookie;
 
   // Pull the IP, port, and authorization info from the message
   ip            = message.getValue( "IP-Address"          );
@@ -210,7 +250,7 @@ void FileTransfer::contactStarted3_ContactConfirmsAccept(const MimeMessage& mess
   portXInternal = message.getValue( "PortX-Internal"      ).toInt();  // As of MSN5
   port          = message.getValue( "Port"                ).toInt();
   portX         = message.getValue( "PortX"               ).toInt();  // As of MSN5
-  authCookie_   = message.getValue( "AuthCookie"          );
+  authCookie    = message.getValue( "AuthCookie"          );
 
 /*
  * This is an attempt to get file transfers
@@ -232,8 +272,8 @@ void FileTransfer::contactStarted3_ContactConfirmsAccept(const MimeMessage& mess
  * Using IP-Address on Port and IP-Address-Internal on PortX-Internal should be sufficient.
  */
 
-  QString externalIP = getExternalIp();
-  if(ip == externalIP)
+  QString externalIp = getExternalIp();
+  if(ip == externalIp)
   {
     // The other client must be at the same network..!
     // Try to connect internally.
@@ -250,12 +290,12 @@ void FileTransfer::contactStarted3_ContactConfirmsAccept(const MimeMessage& mess
 
 
 #ifdef KMESSDEBUG_FILETRANSFER_GENERAL
-  kdDebug() << "FileTransfer - IP: " << ip << " Port: " << port << " AuthCookie: " << authCookie_ << endl;
+  kdDebug() << "FileTransfer::contactStarted3_ContactConfirmsAccept() - IP: " << ip << " Port: " << port << " AuthCookie: " << authCookie << endl;
 #endif
 
   // Initialize the MSNFTP connection
   msnFtpConnection_ = new MsnFtpConnection();
-  msnFtpConnection_->setAuthInfo( CurrentAccount::instance()->getHandle(), authCookie_ );
+  msnFtpConnection_->setAuthInfo( CurrentAccount::instance()->getHandle(), authCookie );
   connectMsnFtpConnection();
 
   // Initialize the progess dialog
@@ -263,15 +303,7 @@ void FileTransfer::contactStarted3_ContactConfirmsAccept(const MimeMessage& mess
   slotMsnFtpStatusMessage( i18n("Connecting to %1, port %2").arg(ip).arg(port), MsnFtpConnection::STATUS_DIALOG );
 
   // Start the transfer
-  bool connected = msnFtpConnection_->retrieveFile(file_, ip, port);
-
-  // Signal when we're failed to connect,
-  // don't display a status message or destroy the object.
-  // The signals of msnftpconnection do this already.
-  if(! connected)
-  {
-    sendCancelMessage(CANCEL_FAILED);
-  }
+  msnFtpConnection_->retrieveFile(file_, ip, port);
 }
 
 
@@ -284,10 +316,10 @@ QString FileTransfer::getAppId()
 
 
 
-// Return a cancel message to the user
-QString FileTransfer::getCancelMessage() const
+// Return a cancel message to display
+QString FileTransfer::getUserAbortMessage() const
 {
-  // Application::getCancelMessage() returns "You have cancelled the session".
+  // Application::getUserAbortMessage() returns "You have cancelled the session".
   return i18n("The transfer was cancelled");
 }
 
@@ -297,35 +329,33 @@ QString FileTransfer::getCancelMessage() const
 void FileTransfer::initializeProgressDialog(bool incoming)
 {
 #ifdef KMESSTEST
-  ASSERT( transferPanel_     == 0 );
   ASSERT( fileSize_          != 0 );
   ASSERT( fileName_.length()  > 0 );
 #endif
 
   // Create a new entry in the tranfer window
-  TransferWindow *transferWindow = TransferWindow::instance();
-  transferPanel_ = transferWindow->addEntry( fileName_, fileSize_, incoming );
+  TransferWindow  *transferWindow = TransferWindow::getInstance();
+  transferID_ = transferWindow->addEntry( fileName_, fileSize_, incoming );
 
   // Connect the dialog so that if the user closes it, it's deleted.
-  connect( transferPanel_,    SIGNAL( cancelTransfer()     ) ,
-           this,              SLOT  ( slotCancelTransfer() ) );
-
-  transferWindow->show();
+  connect( transferWindow, SIGNAL( cancelTransfer(int)     ) ,
+           this,             SLOT( slotCancelTransfer(int) ) );
 }
 
 
 
 // Cancelled the file transfer from the TransferWindow
-void FileTransfer::slotCancelTransfer()
+void FileTransfer::slotCancelTransfer( int transferID )
 {
-#ifdef KMESSDEBUG_FILETRANSFER_GENERAL
-  kdDebug() << "FileTransfer - slotCancelTransfer" << endl;
-#endif
+  // Check if the cancelled transfer is ours
+  if( transferID_ != transferID )
+  {
+    return;
+  }
 
-  // This method is activated from the transferPanel.
-  // cancelClicked() will already call failTransfer()
-  // make sure we don't (or call updateProcess() by accident)
-  transferPanel_ = 0;
+#ifdef KMESSDEBUG_FILETRANSFER_GENERAL
+  kdDebug() << "FileTransfer::slotCancelTransfer()" << endl;
+#endif
 
   // Call userAborted() which cleans up this object correctly
   userAborted();
@@ -333,13 +363,22 @@ void FileTransfer::slotCancelTransfer()
 
 
 
+// The direct connection was established
+void FileTransfer::slotMsnFtpConnectionEstablished()
+{
+  // Update the status dialog
+  slotMsnFtpStatusMessage( i18n("Connection established"), MsnFtpConnection::STATUS_DIALOG );
+  connectionEstablished_ = true;
+}
+
+
+
 // Display a status message
 void FileTransfer::slotMsnFtpStatusMessage(QString message, int statusType)
 {
 #ifdef KMESSDEBUG_FILETRANSFER_GENERAL
-  kdDebug() << "FileTransfer - Status message (type="    << statusType
-                                          << " message=" << message
-                                          << " panel="   << (transferPanel_ != 0) << ")." << endl;
+  kdDebug() << "FileTransfer::slotMsnFtpStatusMessage() - Status message (type="    << statusType
+                                          << " message=" << message << ")." << endl;
 #endif
 
   switch(statusType)
@@ -347,37 +386,36 @@ void FileTransfer::slotMsnFtpStatusMessage(QString message, int statusType)
     // A message for the transfer dialog
     case MsnFtpConnection::STATUS_DIALOG:
     {
-      if(transferPanel_ != 0)
+      // Parse %1 placeholder for filename, and display the message in the transfer window
+      if( message.contains("%1") )
       {
-        // Parse %1 placeholder for filename, and display
-        if(message.contains("%1")) message = message.arg(fileName_);
-        transferPanel_->setStatusMessage( message );
+        message = message.arg( fileName_ );
       }
+      TransferWindow::getInstance()->setStatusMessage( transferID_, message );
       break;
     }
     case MsnFtpConnection::STATUS_DIALOG_FAILED:
     {
-      if(transferPanel_ != 0)
+      if( message.contains("%1") )
       {
-        if(message.contains("%1")) message = message.arg(fileName_);
-        transferPanel_->failTransfer( message );
-        transferPanel_ = 0;
+        message = message.arg( fileName_ );
       }
+      TransferWindow::getInstance()->failTransfer( transferID_, message );
       break;
     }
 
     // A message to display in the chat window
     case MsnFtpConnection::STATUS_CHAT_FAILED:
     {
-      if(message.contains("%1")) message = message.arg("<font color=red>" + shortFileName_ + "</font>");
-      emit appMessage( message );
+      if(message.contains("%1")) message = message.arg("<span class=\"filename failedFilename\">" + shortFileName_ + "</span>");
+      showEventMessage( message, ChatMessage::CONTENT_APP_FAILED, ! isUserStartedApp() );
       break;
     }
     case MsnFtpConnection::STATUS_CHAT:
     default:
     {
-      if(message.contains("%1")) message = message.arg("<font color=blue>" + shortFileName_ + "</font>");
-      emit appMessage( message );
+      if(message.contains("%1")) message = message.arg("<span class=\"filename\">" + shortFileName_ + "</span>");
+      showEventMessage( message, ChatMessage::CONTENT_APP_FAILED, ! isUserStartedApp() );
       break;
     }
   }
@@ -389,16 +427,18 @@ void FileTransfer::slotMsnFtpStatusMessage(QString message, int statusType)
 void FileTransfer::slotMsnFtpTransferComplete()
 {
 #ifdef KMESSDEBUG_FILETRANSFER_GENERAL
-  kdDebug() << "FileTransfer - Successful Transfer" << endl;
+  kdDebug() << "FileTransfer::slotMsnFtpTransferComplete() - Transfer successful." << endl;
 #endif
 
-  // Display a message to the user
-  if( transferPanel_ != 0 )
-  {
-    transferPanel_->finishTransfer();
-    transferPanel_ = 0;
-  }
-  emit fileTransferred(fileName_);
+  // Displays the success in the transfer window
+  TransferWindow::getInstance()->finishTransfer( transferID_ );
+
+  QString shortName = fileName_.right( fileName_.length() - fileName_.findRev("/") - 1 );
+  QString fileURL   = "<a href=\"file:" + fileName_ + "\">" + shortName + "</a>";
+
+  showEventMessage( i18n("Successfully transferred file: %1")
+                    .arg("<span class=\"filename completedFilename\">" + fileURL + "</span>"),
+               ChatMessage::CONTENT_APP_ENDED, ! isUserStartedApp() );
 
   // Terminate this application
   endApplication();
@@ -410,15 +450,20 @@ void FileTransfer::slotMsnFtpTransferComplete()
 void FileTransfer::slotMsnFtpTransferFailed()
 {
 #ifdef KMESSDEBUG_FILETRANSFER_GENERAL
-  kdDebug() << "FileTransfer - Transfer Failed" << endl;
+  kdDebug() << "FileTransfer::slotMsnFtpTransferFailed() - Transfer failed." << endl;
 #endif
 
   // If MsnFtpConnection did not emit a statusMessage(.. STATUS_DIALOG_FAILED) signal
   // the dialog will be terminated with a default message here.
-  if( transferPanel_ != 0 )
+  TransferWindow::getInstance()->failTransfer( transferID_ );
+
+
+  // If the connection attempt failed, send a cancel message.
+  // In other situations, the remote client will notice the MSNFTP connection closed.
+  if( ! connectionEstablished_ )
   {
-    transferPanel_->failTransfer();
-    transferPanel_ = 0;
+    sendCancelMessage(CANCEL_FAILED);  // calls endApplication() already
+    return;
   }
 
   // Terminate this application
@@ -430,9 +475,30 @@ void FileTransfer::slotMsnFtpTransferFailed()
 // Update the progress dialog with the number of bytes transferred.
 void FileTransfer::slotMsnFtpTransferProgess(unsigned long bytesReceived)
 {
-  if ( transferPanel_ != 0 )
+  // Display the progress update in the transfer window
+  TransferWindow::getInstance()->updateProgress( transferID_, bytesReceived );
+}
+
+
+
+// Convert a string to some more readable form
+QString FileTransfer::toReadableBytes(uint bytes)
+{
+  QString format;
+  if(bytes > 1048576)
   {
-    transferPanel_->updateProgress( bytesReceived );
+    // Using '%.2f' instead of '%.1f' removes the ".0" part, but it's less pretty.
+    format.sprintf("%.1f", (double) bytes / 1048576.0);
+    return i18n("%1 MB").arg(format);
+  }
+  else if(bytes > 1024)
+  {
+    format.sprintf("%.1f", (double) bytes / 1024.0);
+    return i18n("%1 kB").arg(format);
+  }
+  else
+  {
+    return i18n("%1 bytes").arg(bytes);
   }
 }
 
@@ -442,62 +508,59 @@ void FileTransfer::slotMsnFtpTransferProgess(unsigned long bytesReceived)
 void FileTransfer::userAborted()
 {
 #ifdef KMESSDEBUG_FILETRANSFER_GENERAL
-  kdDebug() << "FileTransfer - userAborted" << endl;
+  kdDebug() << "FileTransfer::userAborted()" << endl;
 #endif
 
-  // Make sure the transfer panel displays the cancel state
-  if(transferPanel_ != 0)
+  // Display the cancel state in the transfer window
+  TransferWindow::getInstance()->failTransfer( transferID_, i18n("Cancelled") );
+
+  // If there is no MSNFTP connection, the standard behavour is exactly what we need.
+  if(msnFtpConnection_ == 0)
   {
-    // The object can be deleted by the user
-    transferPanel_->failTransfer();
-    transferPanel_ = 0;
+    MimeApplication::userAborted();
+    return;
   }
 
+
+  // We have a MsnFtpConnection listening
   // Then teardown the active transfer
-  if(msnFtpConnection_ != 0)
+  if(msnFtpConnection_->isConnected())
   {
-    // We have a MsnFtpConnection listening
-    if(msnFtpConnection_->isConnected())
-    {
-      // It is already sending the file
-      // Initiate connection teardown
+    // It is already sending the file
+    // Initiate connection teardown
 
-      // Disconnect signals
-      // We are not interested in status messages, they are displayed here already
-      // slotWriteCommand() calls slotMsnFtpTransferFailed() which deletes this object, we do this here already
-      disconnect(msnFtpConnection_, SIGNAL(statusMessage(QString,int)), this, SLOT(slotMsnFtpStatusMessage(QString,int)));
-      disconnect(msnFtpConnection_, SIGNAL(transferFailed()),           this, SLOT(slotMsnFtpTransferFailed()));
+    // Disconnect signals
+    // We are not interested in status messages, they are displayed here already
+    // slotWriteData() calls slotMsnFtpTransferFailed() which deletes this object, we do this here already
+    disconnect(msnFtpConnection_, SIGNAL(statusMessage(QString,int)), this, SLOT(slotMsnFtpStatusMessage(QString,int)));
+    disconnect(msnFtpConnection_, SIGNAL(transferFailed()),           this, SLOT(slotMsnFtpTransferFailed()));
 
-      // Tell MsnFtpConnection to stop transferring. This also signals the other client we cancelled
-      // delete once all signals are processed (since we detached slotMsnFtpTransferFailed())
-      msnFtpConnection_->cancelTransfer(true);
-      msnFtpConnection_->deleteLater();
-      msnFtpConnection_ = 0;
+    // Tell MsnFtpConnection to stop transferring. This also signals the other client we cancelled
+    // delete after all signals are processed (since we detached slotMsnFtpTransferFailed())
+    msnFtpConnection_->cancelTransfer(true);
+    msnFtpConnection_->deleteLater();
+    msnFtpConnection_ = 0;
 
-      // we don't have to send a cancel message anymore.
-      // MsnFtpConnection already does the same thing.
-    }
-    else
-    {
-      // No transfer, but close the connection ASAP
-      msnFtpConnection_->closeConnection();
-      msnFtpConnection_->deleteLater();
-      msnFtpConnection_ = 0;
+    // we don't have to send a cancel message anymore.
+    // MsnFtpConnection already does the same thing.
 
-      // The transfer was not initiated.
-      // Send the cancel-session message (same as Application::userAborted())
-      sendCancelMessage(CANCEL_SESSION);
-    }
+    // Finally delete this object
+    showEventMessage( getUserAbortMessage(), ChatMessage::CONTENT_APP_FAILED, false );
+    endApplication();
+    return;
   }
   else
   {
-    // Same as above
-    sendCancelMessage(CANCEL_SESSION);
+    // No transfer, but close the connection ASAP
+    msnFtpConnection_->closeConnection();
+    msnFtpConnection_->deleteLater();
+    msnFtpConnection_ = 0;
+
+    // The transfer was not initiated.
+    // Send the cancel-session message.
+    MimeApplication::userAborted();
+    return;
   }
-
-
-  // Finally delete this object
-  endApplication( getCancelMessage() );
 }
 
 
@@ -506,43 +569,41 @@ void FileTransfer::userAborted()
 void FileTransfer::userStarted1_UserInvitesContact()
 {
 #ifdef KMESSDEBUG_FILETRANSFER_GENERAL
-  kdDebug() << "FileTransfer - userStarted1_UserInvitesContact" << endl;
+  kdDebug() << "FileTransfer::userStarted1_UserInvitesContact()" << endl;
+#endif
+#ifdef KMESSTEST
+  ASSERT( ! fileName_.isEmpty() );
 #endif
   QString     sizeString;
   MimeMessage message;
 
-  // Show a dialog to get a file path from the user.
-  fileName_ = KFileDialog::getOpenFileName( );
-  if(fileName_.isEmpty()) return;   // user pressed cancel
-
-  // Get a short file name 
+  // Get a short file name so slotMsnFtpStatusMessage() can use that.
   shortFileName_ = fileName_.right( fileName_.length() - fileName_.findRev('/') - 1 );
 
-  // Check if the file truly exists
-  if(! QFile::exists(fileName_))
-  {
-    // Fake an event
-    // No need to show a progress-dialog message, isn't not created here yet
-    slotMsnFtpStatusMessage( i18n("The transfer of %1 failed.  The file doesn't exist."), MsnFtpConnection::STATUS_CHAT );
-    endApplication();
-    return;
-  }
-
-
   // Create a file object
   file_ = new QFile(fileName_);
 
   // Open the file for reading
   bool open = file_->open(IO_ReadOnly);
-  if ( !open )
+  if( ! open )
   {
+    // Notify the user, even if debug mode is not enabled.
+    kdWarning() << "FileTransfer::userStarted1_UserInvitesContact() - Unable to open file: " << fileName_ << "!" << endl;
+
     // Important: undo what we created
     delete file_;
-    file_     = 0;
-    fileName_ = QString::null;
+    file_ = 0;
 
     // Leave
-    slotMsnFtpStatusMessage( i18n("The transfer of %1 failed.  Couldn't open file."), MsnFtpConnection::STATUS_CHAT );
+    if( ! QFile::exists(fileName_) )
+    {
+      slotMsnFtpStatusMessage( i18n("The transfer of %1 failed.  The file does not exist."), MsnFtpConnection::STATUS_CHAT );
+    }
+    else
+    {
+      slotMsnFtpStatusMessage( i18n("The transfer of %1 failed.  The file could not be read."), MsnFtpConnection::STATUS_CHAT );
+    }
+
     endApplication();
     return;
   }
@@ -565,7 +626,7 @@ void FileTransfer::userStarted1_UserInvitesContact()
   sendMessage( message );
 
   // Give the user the option of cancelling the transfer
-  offerCancel( i18n("Sending file %1").arg("<font color=blue>" + shortFileName_ + "</font>") );
+  offerCancel( i18n("Sending file %1").arg("<span class=\"filename invitationFilename\">" + shortFileName_ + "</span>") );
 }
 
 
@@ -574,7 +635,7 @@ void FileTransfer::userStarted1_UserInvitesContact()
 void FileTransfer::userStarted2_ContactAccepts(const MimeMessage& /*message*/)
 {
 #ifdef KMESSDEBUG_FILETRANSFER_GENERAL
-  kdDebug() << "FileTransfer - userStarted2_ContactAccepts" << endl;
+  kdDebug() << "FileTransfer::userStarted2_ContactAccepts()" << endl;
 #endif
 #ifdef KMESSTEST
   ASSERT( msnFtpConnection_ == 0 );
@@ -582,16 +643,17 @@ void FileTransfer::userStarted2_ContactAccepts(const MimeMessage& /*message*/)
 
   QString html;
   QString portString;
+  QString authCookie;
 
   // Create a message showing that the transfer was accepted.
-  emit appMessage( i18n("Transfer accepted.") );
+  showEventMessage( i18n("Transfer accepted."), ChatMessage::CONTENT_APP_STARTED, true );
 
   // Get the authorisation cookie to use
-  authCookie_ = generateCookie();
+  authCookie = generateCookie();
 
   // Initialize the msnftp connection class
   msnFtpConnection_ = new MsnFtpConnection();
-  msnFtpConnection_->setAuthInfo(authHandle_, authCookie_);
+  msnFtpConnection_->setAuthInfo(getContactHandle(), authCookie);
   connectMsnFtpConnection();
 
   // Get the IP,port to use
@@ -601,8 +663,7 @@ void FileTransfer::userStarted2_ContactAccepts(const MimeMessage& /*message*/)
   initializeProgressDialog();
 
   // Set the first status message.
-  // TODO: replace this mesage with something like "Negotiating session parameters"
-  slotMsnFtpStatusMessage( i18n("File transfer dialog message", "Negotiating file transfer mode"), MsnFtpConnection::STATUS_DIALOG );
+  slotMsnFtpStatusMessage( i18n("Negotiating options to connect"), MsnFtpConnection::STATUS_DIALOG );
 
   // Create the invitation message
   // TODO: PortX-Internal and PortX should be another port.
@@ -616,7 +677,7 @@ void FileTransfer::userStarted2_ContactAccepts(const MimeMessage& /*message*/)
   response.addField( "Port",                portString       );
 //  response.addField( "PortX",               portString       );
   response.addField( "Launch-Application",  "FALSE"          );
-  response.addField( "AuthCookie",          authCookie_      );
+  response.addField( "AuthCookie",          authCookie       );
 
   sendMessage( response );
 }
@@ -633,20 +694,12 @@ void FileTransfer::userStarted3_UserPrepares()
 
   if(file_ != 0)
   {
-    bool listening = msnFtpConnection_->sendFile(file_);
-
-    // Signal when we're failed to listen,
-    // don't display a status message or destroy the object.
-    // The signals of msnftpconnection do this already.
-    if(! listening)
-    {
-      sendCancelMessage(CANCEL_FAILED);
-    }
+    msnFtpConnection_->sendFile(file_);
   }
   else
   {
 #ifdef KMESSDEBUG_FILETRANSFER_GENERAL
-    kdDebug() << "FileTransfer::userStarted3_UserPrepares: file_ is a null pointer!" << endl;
+    kdDebug() << "FileTransfer::userStarted3_UserPrepares() Pointer file_ is null!" << endl;
 #endif
     slotMsnFtpTransferFailed();
   }
