@@ -21,21 +21,13 @@
 
 #include <qstring.h>
 
-namespace Applications
-{
-  const int SENDTRANSFER     = 1;
-  const int RECEIVETRANSFER  = 2;
-  const int GNOMEMEETING     = 3;
-  const int REMOTEDESKTOP    = 4;
-}
-
 namespace SpecialGroups
 {
-  const QString INDIVIDUALS = "0";
-  const QString ONLINE      = "96";
-  const QString OFFLINE     = "97";
-  const QString ALLOWED     = "98";
-  const QString REMOVED     = "99";
+  const QString INDIVIDUALS = "individuals";
+  const QString ONLINE      = "online";
+  const QString OFFLINE     = "offline";
+  const QString ALLOWED     = "allowed";
+  const QString REMOVED     = "removed";
 }
 
 #endif
